DynamicSamplingContext

Struct DynamicSamplingContext 

pub struct DynamicSamplingContext { /* private fields */ }
The Dynamic Sampling Context.

Sentry supports sampling at the server level through Dynamic Sampling. This feature allows users to specify target sample rates for each project via the frontend instead of requiring an application redeployment. The backend needs additional information from the SDK to support these features, contained in the Dynamic Sampling Context.

Implementations



impl DynamicSamplingContext

pub fn new() -> DynamicSamplingContext

Creates an empty Dynamic Sampling Context.

pub fn with_trace_id(self, trace_id: TraceId) -> DynamicSamplingContext

Sets the trace ID.

pub fn with_public_key(self, public_key: String) -> DynamicSamplingContext

Sets the DSN public key.

pub fn with_sample_rate(self, sample_rate: f32) -> DynamicSamplingContext

Sets the sample rate.

pub fn with_sample_rand(self, sample_rand: SampleRand) -> DynamicSamplingContext

Sets the sample random value generated by the head of trace SDK.

pub fn with_sampled(self, sampled: bool) -> DynamicSamplingContext

Sets the sampled flag.

pub fn with_release(self, release: String) -> DynamicSamplingContext

Sets the release.

pub fn with_environment(self, environment: String) -> DynamicSamplingContext

Sets the environment.

pub fn with_transaction(self, transaction: String) -> DynamicSamplingContext

Sets the transaction.

pub fn with_org_id(self, org_id: OrganizationId) -> DynamicSamplingContext

Sets the organization ID.