EnvelopeFilterCallbacks

Struct EnvelopeFilterCallbacks 

pub struct EnvelopeFilterCallbacks<F, C> { /* private fields */ }
A container for callbacks that can be passed to Envelope::filter.

Implementations



impl<F, C> EnvelopeFilterCallbacks<F, C>

pub fn new(filter: F, on_filtered: C) -> EnvelopeFilterCallbacks<F, C>

Create a new EnvelopeFilterCallbacks.

filter will be called to determine whether the envelope items should be kept. on_filtered will be called on all envelope items which are then dropped.